Stan Math Library: stan/math/fwd/mat/fun/typedefs.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

typedefs.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_MAT_FUN_TYPEDEFS_HPP
2 #define STAN_MATH_FWD_MAT_FUN_TYPEDEFS_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/fwd/mat/fun/Eigen_NumTraits.hpp>
7
8 namespace stan {
9 namespace math {
10
11 typedef
12 Eigen::Matrix<double, Eigen::Dynamic, Eigen::Dynamic>::Index
13 size_type;
14
15 typedef
16 Eigen::Matrix<fvar<double>, Eigen::Dynamic, Eigen::Dynamic>
17 matrix_fd;
18
19 typedef
20 Eigen::Matrix<fvar<fvar<double> >, Eigen::Dynamic, Eigen::Dynamic>
21 matrix_ffd;
22
23 typedef
24 Eigen::Matrix<fvar<double>, Eigen::Dynamic, 1>
25 vector_fd;
26
27 typedef
28 Eigen::Matrix<fvar<fvar<double> >, Eigen::Dynamic, 1>
29 vector_ffd;
30
31 typedef
32 Eigen::Matrix<fvar<double>, 1, Eigen::Dynamic>
33 row_vector_fd;
34
35 typedef
36 Eigen::Matrix<fvar<fvar<double> >, 1, Eigen::Dynamic>
37 row_vector_ffd;
38
39 }
40 }
41 #endif
core.hpp
stan::math::vector_fd
Eigen::Matrix< fvar< double >, Eigen::Dynamic, 1 > vector_fd
Definition: typedefs.hpp:25
stan
Definition: log_sum_exp.hpp:8
stan::math::matrix_fd
Eigen::Matrix< fvar< double >, Eigen::Dynamic, Eigen::Dynamic > matrix_fd
Definition: typedefs.hpp:17
Eigen_NumTraits.hpp
stan::math::size_type
Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic >::Index size_type
Type for sizes and indexes in an Eigen matrix with double e.
Definition: typedefs.hpp:13
stan::math::matrix_ffd
Eigen::Matrix< fvar< fvar< double > >, Eigen::Dynamic, Eigen::Dynamic > matrix_ffd
Definition: typedefs.hpp:21
stan::math::row_vector_fd
Eigen::Matrix< fvar< double >, 1, Eigen::Dynamic > row_vector_fd
Definition: typedefs.hpp:33
Eigen.hpp
stan::math::row_vector_ffd
Eigen::Matrix< fvar< fvar< double > >, 1, Eigen::Dynamic > row_vector_ffd
Definition: typedefs.hpp:37
stan::math::vector_ffd
Eigen::Matrix< fvar< fvar< double > >, Eigen::Dynamic, 1 > vector_ffd
Definition: typedefs.hpp:29

[ Stan Home Page ] © 2011–2016, Stan Development Team.